@@ -124,25 +124,6 @@ test_that("orbital errors on non-trained parsnip", {
   )
 })
 
-test_that("orbital errors nicely on post-processing", {
-  skip_if_not_installed("workflows")
-  lm_spec <- parsnip::linear_reg()
-
-  wf_spec <- workflows::workflow() |>
-    workflows::add_formula(mpg ~ .) |>
-    workflows::add_model(lm_spec)
-
-  wf_fit <- parsnip::fit(wf_spec, mtcars)
-
-  # fake post-processing happening
-  wf_fit$post$actions <- list(thing = 1)
-
-  expect_snapshot(
-    error = TRUE,
-    orbital(wf_fit)
-  )
-})
-
 test_that("orbital errors on wrong input", {
   expect_snapshot(
     error = TRUE,
